@@ -114,7 +114,7 @@ struct _ExcelWriteState {
 #define FILL_NONE 0
 #define FILL_SOLID 1
 #define FILL_MAGIC FILL_NONE
-#define BORDER_MAGIC STYLE_BORDER_NONE
+#define BORDER_MAGIC GNM_STYLE_BORDER_NONE
 
 typedef enum {
 	STR_NO_LENGTH		= 0,
@@ -141,4 +141,8 @@ int excel_write_get_externsheet_idx (ExcelWriteState *wb,
 
 int excel_write_map_errcode (GnmValue const *v);
 
+/* Shared with xlsx export */
+void excel_sheet_extent (Sheet const *sheet, GnmRange *extent, GnmStyle **col_styles,
+			 int maxcols, int maxrows, IOContext *io_context);
+
 #endif /* GNM_MS_EXCEL_WRITE_H */
