@@ -75,7 +75,7 @@ typedef struct {
 	GtkTreeSelection   *selection;
 	GtkButton *button_rescan_directories;
 	GtkButton *button_directory_add, *button_directory_delete;
-	GtkButton *button_activate_all, *button_deactivate_all;
+	GtkButton *button_activate_all;
 	GtkCheckButton *checkbutton_install_new;
 	GtkWidget *frame_mark_for_deactivation;
 	GtkWidget *checkbutton_mark_for_deactivation;
@@ -458,8 +458,7 @@ cb_pm_selection_changed (GtkTreeSelection *selection, PluginManagerGUI *pm_gui)
 }
 
 static void
-pm_dialog_cleanup (G_GNUC_UNUSED GObject *dialog,
-		   PluginManagerGUI *pm_gui)
+cb_pm_dialog_free (PluginManagerGUI *pm_gui)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL (pm_gui->model_plugins);
 	GtkTreeIter iter;
@@ -478,12 +477,14 @@ pm_dialog_cleanup (G_GNUC_UNUSED GObject *dialog,
 			G_OBJECT (plugin), (GWeakNotify) cb_plugin_destroyed, pm_gui);
 	}
 
-	if (pm_gui->gui != NULL) {
+	if (pm_gui->gui != NULL)
 		g_object_unref (G_OBJECT (pm_gui->gui));
-		pm_gui->gui = NULL;
-	}
-
-	pm_gui->dialog_pm = NULL;
+	if (pm_gui->model_plugins != NULL)
+		g_object_unref (G_OBJECT (pm_gui->model_plugins));
+	if (pm_gui->model_details != NULL)
+		g_object_unref (G_OBJECT (pm_gui->model_details));
+	if (pm_gui->model_directories != NULL)
+		g_object_unref (G_OBJECT (pm_gui->model_directories));
 	g_free (pm_gui);
 }
 
@@ -504,23 +505,6 @@ cb_pm_button_activate_all_clicked (G_GNUC_UNUSED GtkButton *button,
 	}
 }
 
-static void
-cb_pm_button_deactivate_all_clicked (G_GNUC_UNUSED GtkButton *button,
-				     PluginManagerGUI *pm_gui)
-{
-	ErrorInfo *deactivation_error, *error;
-
-	go_plugin_db_deactivate_plugin_list (
-		go_plugins_get_available_plugins (), &deactivation_error);
-	if (deactivation_error != NULL) {
-		error = error_info_new_str_with_details (
-			_("Errors while deactivating plugins"), deactivation_error);
-		gnumeric_error_info_dialog_show (
-			GTK_WINDOW (pm_gui->dialog_pm), error);
-		error_info_free (error);
-	}
-}
-
 static void
 pm_dialog_init (PluginManagerGUI *pm_gui)
 {
@@ -530,9 +514,6 @@ pm_dialog_init (PluginManagerGUI *pm_gui)
 	g_signal_connect (G_OBJECT (pm_gui->button_activate_all),
 		"clicked",
 		G_CALLBACK (cb_pm_button_activate_all_clicked), pm_gui);
-	g_signal_connect (G_OBJECT (pm_gui->button_deactivate_all),
-		"clicked",
-		G_CALLBACK (cb_pm_button_deactivate_all_clicked), pm_gui);
 	g_signal_connect_swapped (G_OBJECT (pm_gui->button_rescan_directories),
 		"clicked",
 		G_CALLBACK (cb_pm_button_rescan_directories_clicked), pm_gui);
@@ -545,9 +526,6 @@ pm_dialog_init (PluginManagerGUI *pm_gui)
 	g_signal_connect (G_OBJECT (pm_gui->checkbutton_install_new),
 		"toggled",
 		G_CALLBACK (cb_pm_checkbutton_install_new_toggled), pm_gui);
-	g_signal_connect (G_OBJECT (pm_gui->dialog_pm),
-		"destroy",
-		G_CALLBACK (pm_dialog_cleanup), pm_gui);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pm_gui->checkbutton_install_new),
 				      gnm_app_prefs->activate_new_plugins);
@@ -564,6 +542,8 @@ pm_dialog_init (PluginManagerGUI *pm_gui)
 	g_slist_free (sorted_plugin_list);
 
 	cb_pm_selection_changed (pm_gui->selection, pm_gui);
+	g_object_set_data_full (G_OBJECT (pm_gui->dialog_pm),
+		"state", pm_gui, (GDestroyNotify) cb_pm_dialog_free);
 }
 
 static void
@@ -594,9 +574,13 @@ cb_active_toggled (G_GNUC_UNUSED GtkCellRendererToggle *celltoggle,
 	GtkTreeIter iter;
 	GOPlugin *plugin;
 	ErrorInfo *error;
+	gboolean has_iter;
 
 	model = gtk_tree_view_get_model (pm_gui->list_plugins);
-	gtk_tree_model_get_iter_from_string (model, &iter, path);
+	has_iter = gtk_tree_model_get_iter_from_string (model, &iter, path);
+
+	g_return_if_fail (has_iter);
+
 	gtk_tree_model_get (model, &iter, PLUGIN_POINTER, &plugin, -1);
 
 	g_return_if_fail (plugin != NULL);
@@ -695,8 +679,6 @@ dialog_plugin_manager (WorkbookControlGUI *wbcg)
 
 	pm_gui->button_activate_all =
 		GTK_BUTTON (glade_xml_get_widget (gui, "button_activate_all"));
-	pm_gui->button_deactivate_all =
-		GTK_BUTTON (glade_xml_get_widget (gui, "button_deactivate_all"));
 	pm_gui->button_rescan_directories = GTK_BUTTON (glade_xml_get_widget
 						    (gui, "button_rescan_directories"));
 	pm_gui->checkbutton_install_new = GTK_CHECK_BUTTON (glade_xml_get_widget
