@@ -33,10 +33,14 @@
 #include "commands.h"
 #include "cmd-edit.h"
 #include "clipboard.h"
+#include "sheet-filter-combo.h"
+#include "widgets/gnm-cell-combo-foo-view.h"
+
 #include <gsf/gsf-impl-utils.h>
 #include <gdk/gdkkeysyms.h>
 #include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-format.h>
+#include <goffice/utils/go-locale.h>
 #include <string.h>
 
 #define SCROLL_LOCK_MASK GDK_MOD5_MASK
@@ -70,7 +74,7 @@ gnm_canvas_object_key_press (GnmCanvas *gcanvas, GdkEventKey *ev)
 
 	switch (ev->keyval) {
 	case GDK_Escape:
-		scg_mode_edit (sc);
+		scg_mode_edit (scg);
 		gnm_app_clipboard_unant ();
 		return TRUE;
 
@@ -145,6 +149,7 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 	WorkbookControlGUI *wbcg = scg->wbcg;
 	gboolean delayed_movement = FALSE;
 	gboolean jump_to_bounds = event->state & GDK_CONTROL_MASK;
+	gboolean is_enter = FALSE;
 	int state = gnumeric_filter_modifiers (event->state);
 	void (*movefn) (SheetControlGUI *, int n,
 			gboolean jump, gboolean horiz);
@@ -168,6 +173,9 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 	switch (event->keyval) {
 	case GDK_KP_Left:
 	case GDK_Left:
+		if (event->state & GDK_MOD1_MASK)
+			return TRUE; /* Alt is used for accelerators */
+
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (scg, gcanvas->first.col - 1);
 		else if (transition_keys && jump_to_bounds) {
@@ -182,6 +190,9 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 
 	case GDK_KP_Right:
 	case GDK_Right:
+		if (event->state & GDK_MOD1_MASK)
+			return TRUE; /* Alt is used for accelerators */
+
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (scg, gcanvas->first.col + 1);
 		else if (transition_keys && jump_to_bounds) {
@@ -209,6 +220,27 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 
 	case GDK_KP_Down:
 	case GDK_Down:
+		if ((event->state == GDK_MOD1_MASK)) {
+			SheetObject *so;
+			if (NULL == (so = sv_wbv (sv)->validation_combo)) {
+				GnmRange r;
+				GSList *objs = sheet_objects_get (sheet,
+					range_init_cellpos (&r, &sv->edit_pos),
+					GNM_FILTER_COMBO_TYPE);
+				if (objs != NULL) {
+					so = objs->data,
+					g_slist_free (objs);
+				}
+			}
+
+			if (NULL != so) {
+				SheetObjectView	*sov = sheet_object_get_view (so,
+					(SheetObjectViewContainer *)gcanvas->pane);
+				gnm_cell_combo_foo_view_popdown (sov);
+				break;
+			}
+		}
+
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_top_row (scg, gcanvas->first.row + 1);
 		else if (transition_keys && jump_to_bounds) {
@@ -313,7 +345,7 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 		if (gnm_canvas_guru_key (wbcg, event))
 			break;
 		if (state == GDK_SHIFT_MASK) {
-			scg_mode_edit (sc);
+			scg_mode_edit (scg);
 			sv_selection_cut (sv, WORKBOOK_CONTROL (wbcg));
 		} else
 			cmd_selection_clear (WORKBOOK_CONTROL (wbcg), CLEAR_VALUES);
@@ -333,6 +365,7 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 			return gtk_widget_event (
 				GTK_WIDGET (gnm_expr_entry_get_entry (wbcg_get_entry_logical (wbcg))),
 				(GdkEvent *) event);
+		is_enter = TRUE;
 		/* fall down */
 
 	case GDK_Tab:
@@ -346,12 +379,19 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event,
 			sheet = wbcg->wb_control.editing_sheet;
 
 		if (wbcg_edit_finish (wbcg, WBC_EDIT_ACCEPT, NULL)) {
-			/* Figure out the direction */
-			gboolean const direction = (event->state & GDK_SHIFT_MASK) ? FALSE : TRUE;
-			gboolean const horizontal = (event->keyval == GDK_KP_Enter ||
-						     event->keyval == GDK_Return) ? FALSE : TRUE;
-
-			sv_selection_walk_step (sv, direction, horizontal);
+			if ((event->state & GDK_MOD1_MASK) &&
+			    (event->state & GDK_CONTROL_MASK) &&
+			    !is_enter) {
+				if (event->state & GDK_SHIFT_MASK)
+					workbook_cmd_dec_indent (sc->wbc);
+				else
+					workbook_cmd_inc_indent	(sc->wbc);
+			} else {
+				/* Figure out the direction */
+				gboolean forward = (event->state & GDK_SHIFT_MASK) ? FALSE : TRUE;
+				gboolean horizontal = !is_enter;
+				sv_selection_walk_step (sv, forward, horizontal);
+			}
 		}
 		break;
 
@@ -647,7 +687,7 @@ gnm_canvas_commit_cb (GtkIMContext *context, const gchar *str, GnmCanvas *gcanva
 		return;
 
 	if (gcanvas->insert_decimal) {
-		GString const *s = format_get_decimal ();
+		GString const *s = go_locale_get_decimal ();
 		str = s->str;
 		length = s->len;
 	} else
@@ -811,7 +851,7 @@ gnm_canvas_new (SheetControlGUI *scg, GnmPane *pane)
 int
 gnm_canvas_find_col (GnmCanvas const *gcanvas, int x, int *col_origin)
 {
-	Sheet const *sheet = ((SheetControl const *) gcanvas->simple.scg)->sheet;
+	Sheet const *sheet = scg_sheet (gcanvas->simple.scg);
 	int col   = gcanvas->first.col;
 	int pixel = gcanvas->first_offset.col;
 
@@ -864,7 +904,7 @@ gnm_canvas_find_col (GnmCanvas const *gcanvas, int x, int *col_origin)
 int
 gnm_canvas_find_row (GnmCanvas const *gcanvas, int y, int *row_origin)
 {
-	Sheet const *sheet = ((SheetControl const *) gcanvas->simple.scg)->sheet;
+	Sheet const *sheet = scg_sheet (gcanvas->simple.scg);
 	int row   = gcanvas->first.row;
 	int pixel = gcanvas->first_offset.row;
 
@@ -915,7 +955,7 @@ gnm_canvas_compute_visible_region (GnmCanvas *gcanvas,
 				   gboolean const full_recompute)
 {
 	SheetControlGUI const * const scg = gcanvas->simple.scg;
-	Sheet const * const sheet = ((SheetControl *) scg)->sheet;
+	Sheet const *sheet = scg_sheet (scg);
 	FooCanvas   *canvas = FOO_CANVAS (gcanvas);
 	int pixels, col, row, width, height;
 
@@ -1011,7 +1051,7 @@ gnm_canvas_compute_visible_region (GnmCanvas *gcanvas,
 
 	/* Update the scrollbar sizes for the primary pane */
 	if (gcanvas->pane->index == 0)
-		scg_scrollbar_config (SHEET_CONTROL (scg));
+		sc_scrollbar_config (SHEET_CONTROL (scg));
 
 	/* Force the cursor to update its bounds relative to the new visible region */
 	gnm_pane_reposition_cursors (gcanvas->pane);
@@ -1544,7 +1584,7 @@ gnm_canvas_object_autoscroll (GnmCanvas *gcanvas, GdkDragContext *context,
 		dx = 0;
 
 	g_object_set_data (&context->parent_instance,
-		"wbcg", scg_get_wbcg (scg));
+		"wbcg", scg_wbcg (scg));
 	gcanvas->sliding_dx    = dx;
 	gcanvas->sliding_dy    = dy;
 	gcanvas->slide_handler = &cb_obj_autoscroll;
