@@ -34,6 +34,7 @@
 #include "mstyle.h"
 #include <goffice/utils/go-glib-extras.h>
 #include <goffice/utils/go-format.h>
+#include <goffice/utils/go-locale.h>
 #include <value.h>
 #include <number-match.h>
 
@@ -362,7 +363,7 @@ go_conf_get_value_as_str (GOConfNode *node, gchar const *key)
 		value_string = g_strdup_printf ("%f", go_conf_get_double (node, key));
 		break;
 	case G_TYPE_BOOLEAN:
-		value_string = g_strdup (format_boolean (go_conf_get_bool (node, key)));
+		value_string = g_strdup (go_locale_boolean_name (go_conf_get_bool (node, key)));
 		break;
 	default:
 		value_string = g_strdup ("ERROR FIXME");
@@ -820,7 +821,7 @@ go_conf_get_str_list (GOConfNode *node, gchar const *key)
 	gint i;
 
 	if ((ptr = go_conf_get_string (node, key)) != NULL) {
-		str_list = g_strsplit ((const gchar *) ptr, "\n", 0);
+		str_list = g_strsplit ((gchar const *) ptr, "\n", 0);
 		for (i = 0; str_list[i]; ++i)
 			list = g_slist_prepend (list, g_strcompress (str_list[i]));
 		list = g_slist_reverse (list);
@@ -994,7 +995,7 @@ go_conf_get_value_as_str (GOConfNode *node, gchar const *key)
 		value_string = go_conf_get_string (node, key);
 		break;
 	case G_TYPE_BOOLEAN:
-		value_string = g_strdup (format_boolean (go_conf_get_bool (node, key)));
+		value_string = g_strdup (go_locale_boolean_name (go_conf_get_bool (node, key)));
 		break;
 	default:
 		value_string = g_strdup ("ERROR FIXME");
@@ -1189,7 +1190,7 @@ go_conf_set_double (GOConfNode *node, gchar const *key, gnm_float val)
 	gchar str[G_ASCII_DTOSTR_BUF_SIZE];
 
 	g_ascii_dtostr (str, sizeof (str), val);
-	g_key_file_set_value (key_file, DOUBLE_GROUP, key, str);
+	g_key_file_set_value (key_file, DOUBLE_GROUP, real_key, str);
 	g_free (real_key);
 }
 
@@ -1222,7 +1223,7 @@ go_conf_set_str_list (GOConfNode *node, gchar const *key, GSList *list)
 	}
 
 	g_key_file_set_string_list (key_file, STRLIST_GROUP, real_key, 
-				    (const gchar **const) strs, ns);
+				    (gchar const **const) strs, ns);
 	g_free (real_key);
 
 	for (i = 0; i < ns; i++)
@@ -1616,6 +1617,8 @@ gnm_conf_init_essential (void)
 		(node, PRINTSETUP_GCONF_MARGIN_TOP, 0.0, 10000.0, 120.0);
 	prefs.print_margin_bottom.points = go_conf_load_double 
 		(node, PRINTSETUP_GCONF_MARGIN_BOTTOM, 0.0, 10000.0, 120.0);
+
+#ifdef WITH_GNOME_PRINT
 	{
 		/* Note: the desired display unit is stored in the  */
 		/* printer config. So we are never using this field */
@@ -1626,6 +1629,8 @@ gnm_conf_init_essential (void)
 		prefs.print_margin_bottom.desired_display 
 			= prefs.print_margin_top.desired_display;
 	}
+#endif
+
 	prefs.print_all_sheets = go_conf_load_bool (
 		node, PRINTSETUP_GCONF_ALL_SHEETS, TRUE);
 	prefs.printer_header = go_conf_load_str_list (node, PRINTSETUP_GCONF_HEADER);
@@ -1745,6 +1750,15 @@ gnm_conf_shutdown (void)
 	}
 	g_hash_table_destroy (prefs.toolbars);
 	g_hash_table_destroy (prefs.toolbar_positions);
+
+	go_slist_free_custom ((GSList *)prefs.plugin_file_states,
+			      (GFreeFunc)g_free);
+	prefs.plugin_file_states = NULL;
+
+	go_slist_free_custom ((GSList *)prefs.file_history_files,
+			      (GFreeFunc)g_free);
+	prefs.file_history_files = NULL;
+
 	go_conf_free_node (root);
 	go_conf_shutdown ();
 }
@@ -1762,8 +1776,8 @@ gnm_gconf_set_plugin_file_states (GSList *list)
 
 	/* the const_casts are ok, the const in the header is just to keep
 	 * people for doing stupid things */
-	g_slist_foreach ((GSList *)prefs.plugin_file_states, (GFunc)g_free, NULL);
-	g_slist_free ((GSList *)prefs.plugin_file_states);
+	go_slist_free_custom ((GSList *)prefs.plugin_file_states,
+			      (GFreeFunc)g_free);
 	prefs.plugin_file_states = list;
 
 	go_conf_set_str_list (root, PLUGIN_GCONF_DIR "/" PLUGIN_GCONF_FILE_STATES, list);
@@ -2016,7 +2030,7 @@ gnm_gconf_set_gui_zoom (gnm_float val)
 {
 	prefs.zoom = val;
 	go_conf_set_double (
-		root, GNM_CONF_GUI_DIR "/" GNM_CONF_GUI_WINDOW_Y, val);
+		root, GNM_CONF_GUI_DIR "/" GNM_CONF_GUI_ZOOM, val);
 }
 
 void     
@@ -2225,7 +2239,7 @@ gnm_gconf_set_gui_resolution_v (gnm_float val)
 }
 
 gboolean
-gnm_gconf_get_toolbar_visible (const char *name)
+gnm_gconf_get_toolbar_visible (char const *name)
 {
 	gpointer pval;
 	char *key = g_strconcat (GNM_CONF_GUI_DIR "/" GNM_CONF_GUI_TOOLBARS "/",
@@ -2250,7 +2264,7 @@ gnm_gconf_get_toolbar_visible (const char *name)
 }
 
 void
-gnm_gconf_set_toolbar_visible (const char *name, gboolean vis)
+gnm_gconf_set_toolbar_visible (char const *name, gboolean vis)
 {
 	char *key = g_strconcat (GNM_CONF_GUI_DIR "/" GNM_CONF_GUI_TOOLBARS "/",
 				 name,
@@ -2267,7 +2281,7 @@ gnm_gconf_set_toolbar_visible (const char *name, gboolean vis)
  * Actually returns a GtkPositionType.
  */
 int
-gnm_gconf_get_toolbar_position (const char *name)
+gnm_gconf_get_toolbar_position (char const *name)
 {
 	gpointer pval;
 	char *key = g_strconcat (GNM_CONF_GUI_DIR "/" GNM_CONF_GUI_TOOLBARS "/",
@@ -2294,7 +2308,7 @@ gnm_gconf_get_toolbar_position (const char *name)
 }
 
 void
-gnm_gconf_set_toolbar_position (const char *name, int pos)
+gnm_gconf_set_toolbar_position (char const *name, int pos)
 {
 	char *key;
 
