@@ -26,28 +26,21 @@
 #include "rendered-value.h"
 
 #include "expr.h"
-#include "gutils.h"
 #include "cell.h"
 #include "style.h"
 #include "style-color.h"
 #include "style-font.h"
 #include "style-border.h"
-#include "number-match.h"
 #include "sheet.h"
 #include "sheet-merge.h"
-#include "sheet-style.h"
 #include "gnm-format.h"
 #include "value.h"
-#include "parse-util.h"
-#include "sheet-control-gui.h"
-#include "str.h"
 #include "workbook.h"
 
-#include <math.h>
 #include <string.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <goffice/utils/go-font.h>
 
-#define BUG_105322
 #undef DEBUG_BOUNDING_BOX
 
 #ifndef USE_RV_POOLS
@@ -55,7 +48,7 @@
 #endif
 
 #if USE_RV_POOLS
-/* Memory pool for RenderedValue.  */
+/* Memory pool for GnmRenderedValue.  */
 static GOMemChunk *rendered_value_pool;
 static GOMemChunk *rendered_rotated_value_pool;
 #define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
@@ -66,132 +59,26 @@ static GOMemChunk *rendered_rotated_value_pool;
 #endif
 
 
-static int minus_utf8_len;
-static char minus_utf8[6];
-
 static guint16
 calc_indent (PangoContext *context, const GnmStyle *mstyle, double zoom)
 {
 	int indent = 0;
 	if (gnm_style_is_element_set (mstyle, MSTYLE_INDENT)) {
-		indent = gnm_style_get_indent (mstyle);
-		if (indent) {
+		int n = gnm_style_get_indent (mstyle);
+		if (n) {
 			GnmFont *style_font = gnm_style_get_font (mstyle, context, zoom);
-			indent *= style_font->approx_width.pixels.digit;
-			style_font_unref (style_font);
+			indent = PANGO_PIXELS (n * style_font->go.metrics->avg_digit_width);
 		}
 	}
 	return MIN (indent, 65535);
 }
 
-/**
- * rendered_value_render :
- *
- * returns TRUE if the result depends on the width of the cell
- **/
-static gboolean
-rendered_value_render (GString *str,
-		       GnmCell const *cell,
-		       PangoContext *context, GnmStyle const *mstyle,
-		       gboolean allow_variable_width, double zoom,
-		       gboolean *display_formula,
-		       GOColor *go_color)
-{
-	Sheet const *sheet = cell->base.sheet;
-
-	/* Is the format variable,  we may ignore it, but we still need to know
-	 * if it is possible */
-	gboolean is_variable_width = FALSE;
-
-	*display_formula = cell_has_expr (cell) && sheet && sheet->display_formulas;
-
-	if (*display_formula) {
-		GnmParsePos pp;
-		g_string_append_c (str, '=');
-		gnm_expr_as_gstring (str, cell->base.expression,
-				     parse_pos_init_cell (&pp, cell),
-				     sheet->convs);
-		*go_color = 0;
-	} else if (sheet && sheet->hide_zero && cell_is_zero (cell)) {
-		*go_color = 0;
-	} else if (gnm_style_is_element_set (mstyle, MSTYLE_FORMAT)) {
-		gboolean handle_minus;
-		double col_width = -1.;
-		/* entered text CAN be null if called by set_value */
-		GOFormat *format = gnm_style_get_format (mstyle);
-
-		/* For format general approximate the cell width in characters */
-		if (style_format_is_var_width (format)) {
-			gboolean is_rotated = (gnm_style_get_rotation (mstyle) != 0);
-			is_variable_width = !is_rotated &&
-				(VALUE_FMT (cell->value) == NULL ||
-				 style_format_is_var_width (VALUE_FMT (cell->value)));
-			if (is_variable_width && allow_variable_width) {
-				GnmFont *style_font = gnm_style_get_font (mstyle, context, zoom);
-				double wdigit = style_font->approx_width.pts.digit;
-
-				if (wdigit > 0.0) {
-					double cell_width;
-					if (cell_is_merged (cell)) {
-						GnmRange const *merged =
-							sheet_merge_is_corner (sheet, &cell->pos);
-
-						cell_width = sheet_col_get_distance_pts (sheet,
-							merged->start.col, merged->end.col + 1);
-					} else
-						cell_width = cell->col_info->size_pts;
-					cell_width -= cell->col_info->margin_a + cell->col_info->margin_b;
-
-#if 0 /* too restrictive for now, do something more accurate later */
-					/*
-					 * FIXME: we should really pass these to the format function,
-					 * so we can measure actual characters, not just what might be
-					 * there.
-					 */
-					cell_width -= MAX (0.0, style_font->approx_width.pts.e - wdigit);
-					cell_width -= MAX (0.0, style_font->approx_width.pts.decimal - wdigit);
-					cell_width -= 2 * MAX (0.0, style_font->approx_width.pts.sign - wdigit);
-#endif
-					col_width = cell_width / wdigit;
-				}
-				style_font_unref (style_font);
-			} else if (style_format_is_general (format))
-				format = VALUE_FMT (cell->value);
-		}
-		format_value_gstring (str, format, cell->value, go_color,
-				      col_width,
-				      sheet ? workbook_date_conv (sheet->workbook) : NULL);
-		switch (VALUE_TYPE (cell->value)) {
-		case VALUE_INTEGER:
-			handle_minus = (value_get_as_int (cell->value) < 0);
-			break;
-		case VALUE_FLOAT:
-			handle_minus = (value_get_as_float (cell->value) < 1.0);
-			break;
-		default:
-			handle_minus = FALSE;
-			break;
-		}
-		if (handle_minus) {
-			unsigned i;
-			for (i = 0; i < str->len; i++)
-				if (str->str[i] == '-') {
-					str->str[i] = minus_utf8[0];
-					g_string_insert_len (str, i + 1, minus_utf8 + 1, minus_utf8_len - 1);
-					i += minus_utf8_len - 1;
-				}
-		}
-	} else {
-		g_warning ("No format: serious error");
-	}
-	return is_variable_width;
-}
 
 void
-rendered_value_remeasure (RenderedValue *rv)
+gnm_rendered_value_remeasure (GnmRenderedValue *rv)
 {
 	if (rv->rotation) {
-		RenderedRotatedValue *rrv = (RenderedRotatedValue *)rv;
+		GnmRenderedRotatedValue *rrv = (GnmRenderedRotatedValue *)rv;
 		PangoContext *context = pango_layout_get_context (rv->layout);
 		double sin_a, abs_sin_a, cos_a;
 		int sdx = 0;
@@ -207,7 +94,7 @@ rendered_value_remeasure (RenderedValue *rv)
 		pango_layout_context_changed (rv->layout);
 
 		rrv->linecount = pango_layout_get_line_count (rv->layout);
-		rrv->lines = g_new (struct RenderedRotatedValueInfo, rrv->linecount);
+		rrv->lines = g_new (struct GnmRenderedRotatedValueInfo, rrv->linecount);
 		pango_layout_get_size (rv->layout, &lwidth, NULL);
 
 		rv->layout_natural_height = 0;
@@ -272,7 +159,7 @@ rendered_value_remeasure (RenderedValue *rv)
 
 
 /**
- * rendered_value_new:
+ * gnm_rendered_value_new:
  * @cell:   The cell
  * @mstyle: The mstyle associated with the cell
  * @allow_variable_width : Allow format to depend on column width.
@@ -280,113 +167,79 @@ rendered_value_remeasure (RenderedValue *rv)
  *
  * Formats the value of the cell according to the format style given in @mstyle
  *
- * Return value: a new RenderedValue
+ * Return value: a new GnmRenderedValue
  **/
-RenderedValue *
-rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
-		    gboolean allow_variable_width,
-		    PangoContext *context,
-		    double zoom)
+GnmRenderedValue *
+gnm_rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
+			gboolean allow_variable_width,
+			PangoContext *context,
+			double zoom)
 {
-	RenderedValue	*res;
-	Sheet		*sheet;
+	GnmRenderedValue	*res;
 	GOColor		 fore;
 	PangoLayout     *layout;
 	PangoAttrList   *attrs;
-	gboolean        display_formula;
-	int             rotation;
-
-	/* This screws thread safety (which we don't need).  */
-	static GString  *str = NULL;
+	int              rotation;
+	Sheet const     *sheet;
+	gboolean         displayed_formula;
 
 	g_return_val_if_fail (cell != NULL, NULL);
 	g_return_val_if_fail (cell->value != NULL, NULL);
 	g_return_val_if_fail (context != NULL, NULL);
 
+	/* sheet->workbook can be NULL when called from preview-grid.c  */
+	sheet = cell->base.sheet;
+
+	displayed_formula =
+		gnm_cell_has_expr (cell) && sheet->display_formulas;
+
 	/* Special handling for manual recalc.
 	 * If a cell has a new expression and something tries to display it we
 	 * need to recalc the value */
-	if (cell->base.flags & CELL_HAS_NEW_EXPR) {
-		cell_eval (cell);
+	if (cell->base.flags & GNM_CELL_HAS_NEW_EXPR) {
+		gnm_cell_eval (cell);
 	}
 
-	sheet = cell->base.sheet;
-
-	if (str)
-		g_string_truncate (str, 0);
-	else
-		str = g_string_sized_new (100);
-
 	rotation = gnm_style_get_rotation (mstyle);
-
-	res = CHUNK_ALLOC (RenderedValue,
-			   rotation ? rendered_rotated_value_pool : rendered_value_pool);
-	res->variable_width = rendered_value_render
-		(str, cell, context, mstyle,
-		 allow_variable_width, zoom,
-		 &display_formula, &fore);
-	res->indent_left = res->indent_right = 0;
-	res->numeric_overflow = FALSE;
-	res->hfilled = FALSE;
-	res->vfilled = FALSE;
-	res->wrap_text = gnm_style_get_effective_wrap_text (mstyle);
-	res->effective_halign = style_default_halign (mstyle, cell);
-	res->effective_valign = gnm_style_get_align_v (mstyle);
-	res->rotation = rotation;
 	if (rotation) {
-		RenderedRotatedValue *rrv = (RenderedRotatedValue *)res;
+		static PangoMatrix const id = PANGO_MATRIX_INIT;
+		GnmRenderedRotatedValue *rrv;
 		GnmStyleElement e;
-		static const PangoMatrix id = PANGO_MATRIX_INIT;
+
+		rrv = CHUNK_ALLOC (GnmRenderedRotatedValue, rendered_rotated_value_pool);
+		res = &rrv->rv;
 
 		rrv->rotmat = id;
 		pango_matrix_rotate (&rrv->rotmat, rotation);
 		rrv->linecount = 0;
 		rrv->lines = NULL;
-		res->might_overflow = FALSE;
 
 		res->noborders = TRUE;
 		/* Deliberately exclude diagonals.  */
 		for (e = MSTYLE_BORDER_TOP; e <= MSTYLE_BORDER_RIGHT; e++) {
 			GnmBorder *b = gnm_style_get_border (mstyle, e);
-			if (!style_border_is_blank (b)) {
+			if (!gnm_style_border_is_blank (b)) {
 				res->noborders = FALSE;
 				break;
 			}
 		}
 	} else {
-		res->might_overflow =
-			cell_is_number (cell) &&
-			!display_formula;
+		res = CHUNK_ALLOC (GnmRenderedValue, rendered_value_pool);
 		res->noborders = FALSE;
 	}
+	res->rotation = rotation;
 
 	res->layout = layout = pango_layout_new (context);
-	pango_layout_set_text (layout, str->str, str->len);
+	res->hfilled = FALSE;
+	res->vfilled = FALSE;
+	res->variable_width = FALSE;
+	res->drawn = FALSE;
+
+	/* ---------------------------------------- */
 
 	attrs = gnm_style_get_pango_attrs (mstyle, context, zoom);
-#ifdef BUG_105322
-	/* See http://bugzilla.gnome.org/show_bug.cgi?id=105322 */
-	if (0 == fore) {
-		GnmColor const *c = gnm_style_get_font_color (mstyle);
-		res->go_fore_color = c->go_color;
-	} else
-		res->go_fore_color = fore;
-#else
-	if (color) {
-		PangoAttrList *new_attrs = pango_attr_list_copy (attrs);
-		PangoAttribute *attr;
-
-		pango_attr_list_unref (attrs);
-		attrs = new_attrs;
-		attr = go_color_to_pango (fore, TRUE);
-		attr->start_index = 0;
-		attr->end_index = -1;
-		pango_attr_list_insert (attrs, attr);
-		style_color_unref (color);
-	}
-#endif
-
 #ifdef DEBUG_BOUNDING_BOX
+	/* Make the whole layout end up with a red background.  */
 	{
 		PangoAttrList *new_attrs = pango_attr_list_copy (attrs);
 		PangoAttribute *attr;
@@ -400,18 +253,35 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 	}
 #endif
 
-	if (cell->value != NULL) {
+	/* Add markup.  */
+	{
 		GOFormat const *fmt = VALUE_FMT (cell->value);
-		if (fmt != NULL && style_format_is_markup (fmt)) {
+		if (fmt != NULL && go_format_is_markup (fmt)) {
 			PangoAttrList *orig = attrs;
 			attrs = pango_attr_list_copy (attrs);
-			pango_attr_list_splice (attrs, fmt->markup, 0, 0);
+			pango_attr_list_splice (attrs,
+						go_format_get_markup (fmt),
+						0, 0);
 			pango_attr_list_unref (orig);
 		}
 	}
 	pango_layout_set_attributes (res->layout, attrs);
 	pango_attr_list_unref (attrs);
 
+	/* ---------------------------------------- */
+
+	/*
+	 * Excel actually does something rather weird.  Just like
+	 * everywhere else we just see displayed formulas as
+	 * strings.
+	 */
+	res->wrap_text =
+		(VALUE_IS_STRING (cell->value) || displayed_formula) &&
+		gnm_style_get_effective_wrap_text (mstyle);
+
+	res->effective_valign = gnm_style_get_align_v (mstyle);
+	res->effective_halign = style_default_halign (mstyle, cell);
+	res->indent_left = res->indent_right = 0;
 	switch (res->effective_halign) {
 	case HALIGN_LEFT:
 		res->indent_left = calc_indent (context, mstyle, zoom);
@@ -434,6 +304,7 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 		 */
 		pango_layout_set_single_paragraph_mode (layout, TRUE);
 		pango_layout_set_alignment (layout, PANGO_ALIGN_LEFT);
+		res->variable_width = TRUE;
 		break;
 
 	case HALIGN_RIGHT:
@@ -441,6 +312,7 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 		pango_layout_set_alignment (layout, PANGO_ALIGN_RIGHT);
 		break;
 
+	case HALIGN_DISTRIBUTED:
 	case HALIGN_CENTER:
 	case HALIGN_CENTER_ACROSS_SELECTION:
 		pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
@@ -450,13 +322,104 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 		g_warning ("Line justification style not supported.");
 	}
 
-	rendered_value_remeasure (res);
+	/* ---------------------------------------- */
+
+	res->numeric_overflow = FALSE;
+
+	if (displayed_formula) {
+		GnmParsePos pp;
+		GString *str = g_string_new ("=");
+		gnm_expr_top_as_gstring (str, cell->base.texpr,
+					 parse_pos_init_cell (&pp, cell),
+					 sheet->convs);
+		pango_layout_set_text (layout, str->str, str->len);
+		g_string_free (str, TRUE);
+		fore = 0;
+		res->might_overflow = FALSE;
+	} else if (sheet->hide_zero && gnm_cell_is_zero (cell)) {
+		pango_layout_set_text (layout, "", 0);
+		fore = 0;
+		res->might_overflow = FALSE;
+	} else {
+		int col_width = -1;
+		GOFormat *format = gnm_style_get_format (mstyle);
+		GODateConventions const *date_conv = sheet->workbook
+			? workbook_date_conv (sheet->workbook)
+			: NULL;
+		GnmFont *font = gnm_style_get_font (mstyle, context, zoom);
+		gboolean is_rotated = (rotation != 0);
+		gboolean variable;
+		GOFormatNumberError err;
+
+		if (go_format_is_general (format) && VALUE_FMT (cell->value))
+			format = VALUE_FMT (cell->value);
+
+		res->might_overflow = !is_rotated &&
+			VALUE_IS_FLOAT (cell->value);
+
+		if (go_format_is_general (format))
+			variable = !is_rotated && VALUE_IS_FLOAT (cell->value);
+		else
+			variable = !is_rotated && go_format_is_var_width (format);
+
+		if (variable)
+			res->variable_width = TRUE;
+
+		if (variable && allow_variable_width) {
+			int col_width_pixels;
+
+			if (gnm_cell_is_merged (cell)) {
+				GnmRange const *merged =
+					gnm_sheet_merge_is_corner (sheet, &cell->pos);
+
+				col_width_pixels = sheet_col_get_distance_pixels
+					(sheet,
+					 merged->start.col, merged->end.col + 1);
+			} else {
+				ColRowInfo const *ci = sheet_col_get_info (sheet, cell->pos.col);
+				col_width_pixels = ci->size_pixels;
+			}
+			col_width_pixels -= (GNM_COL_MARGIN + GNM_COL_MARGIN + 1);
+			col_width = col_width_pixels * PANGO_SCALE;
+		}
+
+		err = gnm_format_layout (layout, font->go.metrics, format,
+					 cell->value,
+					 &fore, col_width, date_conv, TRUE);
+
+		switch (err) {
+		case GO_FORMAT_NUMBER_DATE_ERROR:
+			pango_layout_set_text (layout, "", -1);
+			pango_layout_set_alignment (layout, PANGO_ALIGN_LEFT);
+			res->numeric_overflow = TRUE;
+			res->effective_halign = HALIGN_LEFT;
+			break;
+		default:
+			break;
+		}
+	}
+
+	/* ---------------------------------------- */
+
+	/*
+	 * We store the foreground color separately because
+	 * 1. It is [used to be?] slow to store it as an attribute, see
+	 *    http://bugzilla.gnome.org/show_bug.cgi?id=105322
+	 * 2. This way we get to share the attribute list.
+	 */
+	if (0 == fore) {
+		GnmColor const *c = gnm_style_get_font_color (mstyle);
+		res->go_fore_color = c->go_color;
+	} else
+		res->go_fore_color = fore;
+
+	gnm_rendered_value_remeasure (res);
 
 	return res;
 }
 
 void
-rendered_value_destroy (RenderedValue *rv)
+gnm_rendered_value_destroy (GnmRenderedValue *rv)
 {
 	if (rv->layout) {
 		g_object_unref (G_OBJECT (rv->layout));
@@ -464,29 +427,29 @@ rendered_value_destroy (RenderedValue *rv)
 	}
 
 	if (rv->rotation) {
-		RenderedRotatedValue *rrv = (RenderedRotatedValue *)rv;
+		GnmRenderedRotatedValue *rrv = (GnmRenderedRotatedValue *)rv;
 		g_free (rrv->lines);
 		CHUNK_FREE (rendered_rotated_value_pool, rrv);
 	} else
 		CHUNK_FREE (rendered_value_pool, rv);
 }
 
-RenderedValue *
-rendered_value_recontext (RenderedValue *rv, PangoContext *context)
+GnmRenderedValue *
+gnm_rendered_value_recontext (GnmRenderedValue *rv, PangoContext *context)
 {
-	RenderedValue *res;
+	GnmRenderedValue *res;
 	PangoLayout *layout, *olayout;
 
 	if (rv->rotation) {
-		RenderedRotatedValue *rres =
-			CHUNK_ALLOC (RenderedRotatedValue, rendered_rotated_value_pool);
-		res = (RenderedValue *)rres;
+		GnmRenderedRotatedValue *rres =
+			CHUNK_ALLOC (GnmRenderedRotatedValue, rendered_rotated_value_pool);
+		res = (GnmRenderedValue *)rres;
 
-		*rres = *(RenderedRotatedValue *)rv;
+		*rres = *(GnmRenderedRotatedValue *)rv;
 		rres->lines = g_memdup (rres->lines,
-					rres->linecount * sizeof (struct RenderedRotatedValueInfo));
+					rres->linecount * sizeof (struct GnmRenderedRotatedValueInfo));
 	} else {
-		res = CHUNK_ALLOC (RenderedValue, rendered_value_pool);
+		res = CHUNK_ALLOC (GnmRenderedValue, rendered_value_pool);
 		*res = *rv;
 	}
 
@@ -512,169 +475,37 @@ rendered_value_recontext (RenderedValue *rv, PangoContext *context)
 	 * does not support that.
 	 */
 	if (pango_layout_get_line_count (olayout) == 1) {
-		res->wrap_text = FALSE;
 		if (pango_layout_get_line_count (layout) > 1) {
+			res->wrap_text = FALSE;
 			pango_layout_set_width (layout, -1);
 		}
 	}
 
-	rendered_value_remeasure (res);
+	gnm_rendered_value_remeasure (res);
 	return res;
 }
 
 
 /* Return the value as a single string without format infomation.
  */
-const char *
-rendered_value_get_text (RenderedValue const *rv)
+char const *
+gnm_rendered_value_get_text (GnmRenderedValue const *rv)
 {
 	g_return_val_if_fail (rv != NULL, "ERROR");
 	return pango_layout_get_text (rv->layout);
 }
 
-
-/**
- * cell_get_render_color:
- * @cell: the cell from which we want to pull the color from
- *
- * The returned value is a pointer to a PangoColor describing
- * the foreground colour.
- */
-GOColor
-cell_get_render_color (GnmCell const *cell)
-{
-#ifndef BUG_105322
-	PangoAttrList *attrs;
-	PangoAttrIterator *it;
-	PangoAttribute *attr;
-#endif
-
-	g_return_val_if_fail (cell != NULL, 0);
-
-	/* A precursor to just in time rendering Ick! */
-	if (cell->rendered_value == NULL)
-		cell_render_value ((GnmCell *)cell, TRUE);
-
-#ifdef BUG_105322
-	return cell->rendered_value->go_fore_color;
-#else
-	attrs = pango_layout_get_attributes (cell->rendered_value->layout);
-	g_return_val_if_fail (attrs != NULL, NULL);
-
-	it = pango_attr_list_get_iterator (attrs);
-	attr = pango_attr_iterator_get (it, PANGO_ATTR_FOREGROUND);
-	pango_attr_iterator_destroy (it);
-	if (!attr)
-		return NULL;
-
-	return &((PangoAttrColor *)attr)->color;
-#endif
-}
-
-/**
- * cell_get_entered_text:
- * @cell: the cell from which we want to pull the content from
- *
- * This returns a g_malloc()ed region of memory with a text representation
- * of the cell contents.
- *
- * This will return a text expression if the cell contains a formula, or
- * a string representation of the value.
- */
-char *
-cell_get_entered_text (GnmCell const *cell)
-{
-	g_return_val_if_fail (cell != NULL, NULL);
-
-	if (cell_has_expr (cell)) {
-		GnmParsePos pp;
-		GString *res = g_string_new ("=");
-
-		gnm_expr_as_gstring (res, cell->base.expression,
-				     parse_pos_init_cell (&pp, cell),
-				     cell->base.sheet->convs);
-		return g_string_free (res, FALSE);
-	}
-
-	if (cell->value != NULL) {
-		if (cell->value->type == VALUE_STRING) {
-			/* Try to be reasonably smart about adding a leading quote */
-			char const *tmp = cell->value->v_str.val->str;
-
-			if (tmp[0] != '\'' && !gnm_expr_char_start_p (tmp)) {
-				GnmValue *val = format_match_number (tmp,
-					cell_get_format	(cell),
-					workbook_date_conv (cell->base.sheet->workbook));
-				if (val == NULL)
-					return g_strdup (tmp);
-				value_release (val);
-			}
-			return g_strconcat ("\'", tmp, NULL);
-		}
-		return format_value (NULL, cell->value, NULL, -1,
-			workbook_date_conv (cell->base.sheet->workbook));
-	}
-
-	g_warning ("A cell with no expression, and no value ??");
-	return g_strdup ("<ERROR>");
-}
-
-/*
- * Return the height of the rendered layout after rotation.
- */
-int
-cell_rendered_height (GnmCell const *cell)
-{
-	const RenderedValue *rv;
-
-	g_return_val_if_fail (cell != NULL, 0);
-
-	rv = cell->rendered_value;
-	if (!rv)
-		return 0;
-
-	return PANGO_PIXELS (cell->rendered_value->layout_natural_height);
-}
-
-/*
- * Return the width of the rendered layout after rotation.
- */
-int
-cell_rendered_width (GnmCell const *cell)
-{
-	const RenderedValue *rv;
-
-	g_return_val_if_fail (cell != NULL, 0);
-
-	rv = cell->rendered_value;
-	if (!rv)
-		return 0;
-
-	return PANGO_PIXELS (cell->rendered_value->layout_natural_width);
-}
-
-int
-cell_rendered_offset (GnmCell const * cell)
-{
-	if (!cell || !cell->rendered_value)
-		return 0;
-
-	return cell->rendered_value->indent_left +
-		cell->rendered_value->indent_right;
-}
-
 void
-rendered_value_init (void)
+gnm_rendered_value_init (void)
 {
-	minus_utf8_len = g_unichar_to_utf8 (UNICODE_MINUS_SIGN_C, minus_utf8);
 #if USE_RV_POOLS
 	rendered_value_pool =
 		go_mem_chunk_new ("rendered value pool",
-				  sizeof (RenderedValue),
+				  sizeof (GnmRenderedValue),
 				  16 * 1024 - 128);
 	rendered_rotated_value_pool =
 		go_mem_chunk_new ("rendered rotated value pool",
-				  sizeof (RenderedRotatedValue),
+				  sizeof (GnmRenderedRotatedValue),
 				  16 * 1024 - 128);
 #endif
 }
@@ -683,14 +514,14 @@ rendered_value_init (void)
 static void
 cb_rendered_value_pool_leak (gpointer data, gpointer user)
 {
-	RenderedValue *rendered_value = data;
+	GnmRenderedValue *rendered_value = data;
 	fprintf (stderr, "Leaking rendered value at %p [%s].\n",
 		 rendered_value, pango_layout_get_text (rendered_value->layout));
 }
 #endif
 
 void
-rendered_value_shutdown (void)
+gnm_rendered_value_shutdown (void)
 {
 #if USE_RV_POOLS
 	go_mem_chunk_foreach_leak (rendered_value_pool, cb_rendered_value_pool_leak, NULL);
