@@ -43,6 +43,7 @@
 #include "parse-util.h"
 #include <goffice/utils/datetime.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <goffice/utils/go-locale.h>
 #include <goffice/utils/go-format.h>
 
 #include <stdlib.h>
@@ -590,6 +591,10 @@ stf_parse_csv_cell (GString *text, Source_t *src, StfParseOptions_t *parseoption
 		if ((parseoptions->trim_spaces & TRIM_TYPE_LEFT) == 0)
 			break;
 
+		if (stf_parse_csv_is_separator (cur, parseoptions->sep.chr,
+						parseoptions->sep.str))
+			break;
+
 		if (!g_unichar_isspace (g_utf8_get_char (cur)))
 			break;
 		cur = g_utf8_next_char (cur);
@@ -683,8 +688,10 @@ stf_parse_csv_line (Source_t *src, StfParseOptions_t *parseoptions)
 
 	while (1) {
 		GString *text = g_string_sized_new (30);
-
-		switch (stf_parse_csv_cell (text, src, parseoptions)) {
+		StfParseCellRes res =
+			stf_parse_csv_cell (text, src, parseoptions);
+		trim_spaces_inplace (text->str, parseoptions);
+		switch (res) {
 		case STF_CELL_FIELD_NO_SEP:
 			g_ptr_array_add (line, g_string_free (text, FALSE));
 			cont = FALSE;
@@ -1334,7 +1341,7 @@ stf_parse_options_guess (char const *data)
 	GPtrArray *lines;
 	int tabcount;
 	int sepcount;
-	gunichar sepchar = go_format_get_arg_sep ();
+	gunichar sepchar = go_locale_get_arg_sep ();
 
 	g_return_val_if_fail (data != NULL, NULL);
 
@@ -1360,7 +1367,7 @@ stf_parse_options_guess (char const *data)
 		 * could very easily occur in text are put last.
 		 */
 		if (count_character (lines, (c = sepchar), 0.5) > 0 ||
-		    count_character (lines, (c = go_format_get_col_sep ()), 0.5) > 0 ||
+		    count_character (lines, (c = go_locale_get_col_sep ()), 0.5) > 0 ||
 		    count_character (lines, (c = ':'), 0.5) > 0 ||
 		    count_character (lines, (c = ','), 0.5) > 0 ||
 		    count_character (lines, (c = ';'), 0.5) > 0 ||
