@@ -59,8 +59,8 @@ GnmValidation *validation_new   (ValidationStyle style,
 				 GnmExprTop const *texpr1,
 				 gboolean allow_blank, gboolean use_dropdown);
 
-void        validation_ref    (GnmValidation *v);
-void        validation_unref  (GnmValidation *v);
+void        validation_ref    (GnmValidation const *v);
+void        validation_unref  (GnmValidation const *v);
 ValidationStatus validation_eval (WorkbookControl *wbc, GnmStyle const *mstyle,
 				  Sheet *sheet, GnmCellPos const *pos,
 				  gboolean *showed_dialog);
