@@ -9,7 +9,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "value.h"
 
@@ -32,6 +32,7 @@
 #include <cell.h>
 #include <number-match.h>
 #include <goffice/utils/go-glib-extras.h>
+#include <goffice/utils/go-locale.h>
 
 #ifndef USE_VALUE_POOLS
 #define USE_VALUE_POOLS 1
@@ -202,7 +203,7 @@ value_error_set_pos (GnmValueErr *err, GnmEvalPos const *pos)
     g_return_val_if_fail (err != NULL, NULL);
     g_return_val_if_fail (VALUE_IS_ERROR (err), NULL);
 
-    err->src = *pos;
+    /* err->src = *pos; */
     return (GnmValue *)err;
 }
 
@@ -343,8 +344,9 @@ value_new_cellrange_r (Sheet *sheet, GnmRange const *r)
  * value_new_cellrange_str :
  * @sheet: the sheet where the cell range is evaluated. This really only needed if
  *         the range given does not include a sheet specification.
- * @str: a range specification (ex: "A1", "A1:C3", "Sheet1!A1:C3).
+ * @str: a range specification (ex: "A1", "A1:C3", "Sheet1!A1:C3", "R1C1").
  *
+ * Parse @str using the convention associated with @sheet.
  * Returns a (GnmValue *) of type VALUE_CELLRANGE if the @range was
  * succesfully parsed or NULL on failure.
  */
@@ -361,8 +363,7 @@ value_new_cellrange_str (Sheet *sheet, char const *str)
 		parse_pos_init_sheet (&pp, sheet),
 		GNM_EXPR_PARSE_FORCE_EXPLICIT_SHEET_REFERENCES |
 		GNM_EXPR_PARSE_UNKNOWN_NAMES_ARE_STRINGS,
-		gnm_expr_conventions_default,
-		NULL);
+		NULL, NULL);
 
 	if (texpr != NULL)  {
 		GnmValue *value = gnm_expr_top_get_range (texpr);
@@ -419,21 +420,21 @@ value_new_array_empty (guint cols, guint rows)
  * Returns TRUE, FALSE, or -1.
  */
 static int
-value_parse_boolean (const char *str, gboolean translated)
+value_parse_boolean (char const *str, gboolean translated)
 {
 	if (translated) {
 		/* FIXME: ascii???  */
-		if (0 == g_ascii_strcasecmp (str, format_boolean (TRUE)))
-			return TRUE;
-		else if (0 == g_ascii_strcasecmp (str, format_boolean (FALSE)))
-			return FALSE;
+		if (0 == g_ascii_strcasecmp (str, go_locale_boolean_name (TRUE)))
+			return +TRUE;
+		else if (0 == g_ascii_strcasecmp (str, go_locale_boolean_name (FALSE)))
+			return +FALSE;
 		else
 			return -1;
 	} else {
 		if (0 == g_ascii_strcasecmp (str, "TRUE"))
-			return TRUE;
+			return +TRUE;
 		else if (0 == g_ascii_strcasecmp (str, "FALSE"))
-			return FALSE;
+			return +FALSE;
 		else
 			return -1;
 	}
@@ -462,7 +463,6 @@ value_new_from_string (GnmValueType t, char const *str, GOFormat *sf,
 		char *end;
 		gnm_float d;
 
-		errno = 0;
 		d = gnm_strto (str, &end);
 		if (str != end && *end == '\0' && errno != ERANGE)
 			res = value_new_float (d);
@@ -600,7 +600,7 @@ value_dup (GnmValue const *src)
 		break;
 
 	case VALUE_ERROR:
-		res = value_new_error_str (&src->v_err.src,
+		res = value_new_error_str (NULL, /* &src->v_err.src, */
 					   src->v_err.mesg);
 		break;
 
@@ -844,7 +844,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		gboolean b = v->v_bool.val;
 		g_string_append (target,
 				 conv->output_translated
-				 ? format_boolean (b)
+				 ? go_locale_boolean_name (b)
 				 : (b ? "TRUE" : "FALSE"));
 		return;
 	}
@@ -866,7 +866,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		if (conv->output_array_row_sep)
 			row_sep = conv->output_array_row_sep;
 		else {
-			locale_row_sep[0] = format_get_row_sep ();
+			locale_row_sep[0] = go_locale_get_row_sep ();
 			locale_row_sep[1] = 0;
 			row_sep = locale_row_sep;
 		}
@@ -874,7 +874,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		if (conv->output_array_col_sep)
 			col_sep = conv->output_array_col_sep;
 		else {
-			locale_col_sep[0] = format_get_col_sep ();
+			locale_col_sep[0] = go_locale_get_col_sep ();
 			locale_col_sep[1] = 0;
 			col_sep = locale_col_sep;
 		}
@@ -1040,6 +1040,12 @@ value_get_as_float (GnmValue const *v)
 	return 0.0;
 }
 
+gboolean
+value_is_zero (GnmValue const *v)
+{
+	return gnm_abs (value_get_as_float (v)) < 64 * GNM_EPSILON;
+}
+
 GnmRangeRef const *
 value_get_rangeref (GnmValue const *v)
 {
@@ -1422,7 +1428,7 @@ find_column_of_field (GnmEvalPos const *ep,
 	        cell = sheet_cell_get (sheet, n, row);
 		if (cell == NULL)
 		        continue;
-		cell_eval (cell);
+		gnm_cell_eval (cell);
 
 		txt = cell->value
 			? value_peek_string (cell->value)
@@ -1542,8 +1548,8 @@ parse_criteria_range (Sheet *sheet, int b_col, int b_row, int e_col, int e_row,
 		for (j = b_col; j <= e_col; j++) {
 		        cell = sheet_cell_get (sheet, j, i);
 			if (cell != NULL)
-				cell_eval (cell);
-			if (cell_is_empty (cell))
+				gnm_cell_eval (cell);
+			if (gnm_cell_is_empty (cell))
 			        continue;
 
 			cond = g_new (GnmCriteria, 1);
@@ -1589,8 +1595,8 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue const *database, GnmValu
 	        cell = sheet_cell_get (sheet, i, b_row);
 		if (cell == NULL)
 		        continue;
-		cell_eval (cell);
-		if (cell_is_empty (cell))
+		gnm_cell_eval (cell);
+		if (gnm_cell_is_empty (cell))
 		        continue;
 		field_ind[i - b_col] =
 		        find_column_of_field (ep, database, cell->value);
@@ -1626,8 +1632,8 @@ find_rows_that_match (Sheet *sheet, int first_col, int first_row,
 				cond = cond_ptr->data;
 				test_cell = sheet_cell_get (sheet, cond->column, row);
 				if (test_cell != NULL) {
-					cell_eval (test_cell);
-					if (!cell_is_empty (test_cell) &&
+					gnm_cell_eval (test_cell);
+					if (!gnm_cell_is_empty (test_cell) &&
 					    !cond->fun (test_cell->value, cond->x)) {
 						add_flag = FALSE;
 						break;
@@ -1683,6 +1689,19 @@ filter_row:
 
 /****************************************************************************/
 
+GType
+gnm_value_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GnmValue",
+			 (GBoxedCopyFunc)value_dup,
+			 (GBoxedFreeFunc)value_release);
+	return t;
+}
+/****************************************************************************/
+
 GnmValueErr const value_terminate_err = { VALUE_ERROR, NULL, NULL };
 static GnmValueFloat const the_value_zero = { VALUE_FLOAT, NULL, 0 };
 GnmValue const *value_zero = (GnmValue const *)&the_value_zero;
